#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.7.0.0
visibility:           public
id:                   ormolu-0.7.0.0-3Pz2H27EX0Vcgd0gBhwgh
key:                  ormolu-0.7.0.0-3Pz2H27EX0Vcgd0gBhwgh
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  4de0d890a4fca31a050c7f734c687905
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Imports
    Ormolu.Fixity.Internal Ormolu.Fixity.Parser Ormolu.Fixity.Printer
    Ormolu.Imports Ormolu.Parser Ormolu.Parser.CommentStream
    Ormolu.Parser.Pragma Ormolu.Parser.Result Ormolu.Printer
    Ormolu.Printer.Combinators Ormolu.Printer.Comments
    Ormolu.Printer.Internal Ormolu.Printer.Meat.Common
    Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal
    Ormolu.Terminal.QualifiedDo Ormolu.Utils Ormolu.Utils.Cabal
    Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ormolu-0.7.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ormolu-0.7.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ormolu-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.7.0.0-3Pz2H27EX0Vcgd0gBhwgh
depends:
    Cabal-syntax-3.10.3.0 Diff-1.0-2yeHn0RwQ8bEUz2Oy0D0Hq
    MemoTrie-0.6.11-4i7Xb9XCfLZGsfSBFv3VVS
    ansi-terminal-1.1-3WEwGthe7is1LBGeoKnQZb array-0.5.6.0
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    megaparsec-9.7.1-33tUprDdwFBJhkf3Oz7GVI mtl-2.3.1
    syb-0.7.3-KT9hwgimXgJGhH797KmsNL text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

